var searchData=
[
  ['character_0',['Predefined Musical Character',['../../vstinterfaces/group__musicalCharacter.html',1,'']]],
  ['class_20factory_1',['class factory',['../group__classFactoryMacros.html',1,'Macros for defining the class factory'],['../group__constexprClassFactoryMacros.html',1,'Macros for defining the compile time class factory']]],
  ['class_3a_20interface_20for_20unit_20testing_2',['Test Class: Interface for unit testing',['../../vstinterfaces/group__TestClass.html',1,'']]],
  ['classes_3',['Classes',['../group__hostingBase.html',1,'Common Hosting SDK Implementation Helper Classes'],['../group__sdkBase.html',1,'Common SDK Implementation Helper Classes'],['../group__vstClasses.html',1,'VST Implementation Helper Classes']]],
  ['common_20hosting_20sdk_20implementation_20helper_20classes_4',['Common Hosting SDK Implementation Helper Classes',['../group__hostingBase.html',1,'']]],
  ['common_20sdk_20implementation_20helper_20classes_5',['Common SDK Implementation Helper Classes',['../group__sdkBase.html',1,'']]],
  ['compile_20time_20class_20factory_6',['Macros for defining the compile time class factory',['../group__constexprClassFactoryMacros.html',1,'']]],
  ['context_20of_20state_20restoration_7',['Context of State Restoration',['../../vstinterfaces/group__stateType.html',1,'']]]
];
